@@ -863,9 +863,9 @@ function entityTypeToString(type, plural) {
     case RS.EntityDimAngular:
         return plural ? qsTr("Angular Dimensions") : qsTr("Angular Dimension");
     case RS.EntityDimAngular2L:
-        return plural ? qsTr("2 Line Angular Dimensions") : qsTr("2 Line Angular Dimension");
+        return plural ? qsTr("Angular Dimensions (2 Line)") : qsTr("Angular Dimension (2 Line)");
     case RS.EntityDimAngular3P:
-        return plural ? qsTr("3 Point Angular Dimensions") : qsTr("3 Point Angular Dimension");
+        return plural ? qsTr("Angular Dimensions (3 Point)") : qsTr("Angular Dimension (3 Point)");
     case RS.EntityDimArcLength:
         return plural ? qsTr("Arc Dimension") : qsTr("Arc Dimension");
     case RS.EntityDimDiametric:
@@ -914,6 +914,18 @@ function entityTypeToString(type, plural) {
     }
 }
 
+function translateFilterStrings(filterStrings) {
+    for (var i=0; i<filterStrings.length; i++) {
+        filterStrings[i] = filterStrings[i].replace("All CAD Files", qsTr("All CAD Files"));
+        filterStrings[i] = filterStrings[i].replace("DXF Files", qsTr("DXF Files"));
+        filterStrings[i] = filterStrings[i].replace("SVG Files", qsTr("SVG Files"));
+        filterStrings[i] = filterStrings[i].replace("DXF Drawing", qsTr("DXF Drawing"));
+        filterStrings[i] = filterStrings[i].replace("DWG Drawing", qsTr("DWG Drawing"));
+        filterStrings[i] = filterStrings[i].replace("PDF File", qsTr("PDF File"));
+    }
+    return filterStrings;
+}
+
 /**
  * Checks the type of the given object.
  *
@@ -1339,6 +1351,21 @@ Array.prototype.remove = function(val, compareFunction) {
     }
 };
 
+/**
+ * Removes all matches of the given value from the array.
+ * \param The value(s) to remove.
+ */
+Array.prototype.removeAll = function() {
+    var what, a = arguments, l = a.length, ax;
+    while (l && this.length) {
+        what = a[--l];
+        while ((ax = this.indexOf(what)) !== -1) {
+            this.splice(ax, 1);
+        }
+    }
+    return this;
+};
+
 /**
  * Remove the first case insensitive match of the given string value from the array.
  * \param val The value to remove.
@@ -1384,85 +1411,18 @@ Array.prototype.sortNumerical = function() {
     Array.prototype.sort.call(this, function(a,b) { return a - b });
 }
 
-//Array.alphaNumericalSorter = function(a, b) {
-//    var aVal = parseInt(a);
-//    var bVal = parseInt(b);
-//    if (isNaN(aVal) && isNaN(bVal)) {
-//        // alphabetical:
-//        return a.localeCompare(b);
-//    }
-//    else if (isNaN(aVal)) {
-//        // text before numbers:
-//        return -1;
-//    }
-//    else if (isNaN(bVal)) {
-//        // numbers after texts:
-//        return 1;
-//    }
-//    else {
-//        // nummerical:
-//        return aVal - bVal;
-//    }
-//};
-
-/* alphanum.js (C) Brian Huisman
- * Based on the Alphanum Algorithm by David Koelle
- * The Alphanum Algorithm is discussed at http://www.DaveKoelle.com
- *
- * Distributed under same license as original
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- */
 Array.alphaNumericalSorter = function(a, b) {
-    function chunkify(t) {
-        var tz = new Array();
-        var x = 0, y = -1, n = 0, i, j;
-
-        while (i = (j = t.charAt(x++)).charCodeAt(0)) {
-            var m = (i == 46 || (i >=48 && i <= 57));
-            if (m !== n) {
-                tz[++y] = "";
-                n = m;
-            }
-            tz[y] += j;
-        }
-        return tz;
-    }
-
-    var aa = chunkify(a.toLowerCase());
-    var bb = chunkify(b.toLowerCase());
-
-    for (x = 0; aa[x] && bb[x]; x++) {
-        if (aa[x] !== bb[x]) {
-            var c = Number(aa[x]), d = Number(bb[x]);
-            if (c == aa[x] && d == bb[x]) {
-                return c - d;
-            } else return (aa[x] > bb[x]) ? 1 : -1;
-        }
-    }
-    return aa.length - bb.length;
+    return RS.compareAlphanumerical(a, b);
 };
 
 /**
  * Sorts this array with string items (case insensitive)
  */
-Array.prototype.sortCaseInsensitive = function() {
-    Array.prototype.sort.call(this, function (a, b) {
-        return a.toLowerCase().localeCompare(b.toLowerCase());
-    });
-};
+//Array.prototype.sortCaseInsensitive = function() {
+//    Array.prototype.sort.call(this, function (a, b) {
+//        return a.toLowerCase().localeCompare(b.toLowerCase());
+//    });
+//};
 
 /* Finds the intersection of two sorted arrays.
  *
@@ -1790,7 +1750,7 @@ function coordinateToString(coordinate, decimals, relative, polar, doc) {
     var second;
     var sep;
     if (polar) {
-        sep = RSettings.getStringValue("Input/PolarCoordinateSeparator", "<");
+        sep = RSettings.getPolarCoordinateSeparator();
         if (!isNull(doc)) {
             first = doc.formatLinear(coordinate.getMagnitude());
             second = doc.formatAngle(coordinate.getAngle());
@@ -1801,7 +1761,7 @@ function coordinateToString(coordinate, decimals, relative, polar, doc) {
         }
     }
     else {
-        sep = RSettings.getStringValue("Input/CartesianCoordinateSeparator", ",");
+        sep = RSettings.getCartesianCoordinateSeparator();
         if (!isNull(doc)) {
             first = doc.formatLinear(coordinate.x);
             second = doc.formatLinear(coordinate.y);
@@ -1814,10 +1774,7 @@ function coordinateToString(coordinate, decimals, relative, polar, doc) {
 
     var prefix;
     if (relative) {
-        prefix = RSettings.getStringValue(
-                    "Input/RelativeCoordinatePrefix",
-                    String.fromCharCode(64)  // @ (doxygen can't cope with an @ here)
-        );
+        prefix = RSettings.getRelativeCoordinatePrefix();
     }
     else {
         prefix = "";
@@ -2472,20 +2429,50 @@ function writeTextFile(fileName, str) {
         textStream.writeString(str);
     }
     file.close();
-};
+}
+
+function getKeyboardModifiers(event) {
+    if (!isNull(event)) {
+        if (isFunction(event.getModifiers)) {
+            return event.getModifiers();
+        }
+        else {
+            return event.modifiers();
+        }
+    }
 
-function getKeyboardModifiers() {
     if (RSettings.isQt(5)) {
-        return QGuiApplication.keyboardModifiers();
+        return QGuiApplication.queryKeyboardModifiers();
     }
     else {
-        return QApplication.keyboardModifiers();
+        return QApplication.queryKeyboardModifiers();
     }
-};
+}
 
-function isShiftPressed() {
-    return getKeyboardModifiers().valueOf() & Qt.ShiftModifier.valueOf();
-};
+function isShiftPressed(event) {
+    return (getKeyboardModifiers(event) & Qt.ShiftModifier) > 0 ||
+           (getKeyboardModifiers() & Qt.ShiftModifier) > 0;
+}
+
+function isAltPressed(event) {
+    return (getKeyboardModifiers(event) & Qt.AltModifier) > 0 ||
+           (getKeyboardModifiers() & Qt.AltModifier) > 0;
+}
+
+function isControlPressed(event) {
+    return (getKeyboardModifiers(event) & Qt.ControlModifier) > 0 ||
+           (getKeyboardModifiers() & Qt.ControlModifier) > 0;
+}
+
+function createSpatialIndex() {
+    if (!isNull(global.SpatialIndexClass)) {
+        // use class defined as global variable "SpatialIndexClass":
+        // allows plugins to override the default spatial index class:
+        return new global[global.SpatialIndexClass]();
+    }
+    //return new RSpatialIndexSimple();
+    return new RSpatialIndexNavel();
+}
 
 // Qt 4 API workaround:
 function qsTranslate2(context, sourceText, disambiguation, n) {
